@@ -84,6 +84,18 @@ class BrotherLabelPlugin(LabelPrintingMixin, SettingsMixin, InvenTreePlugin):
             'choices': get_rotation_choices,
             'default': '0',
         },
+        'COMPRESSION': {
+            'name': _('Compression'),
+            'description': _('Enable image compression option (required for some printer models)'),
+            'validator': bool,
+            'default': False,
+        },
+        'HQ': {
+            'name': _('High Quality'),
+            'description': _('Enable high quality option (required for some printers)'),
+            'validator': bool,
+            'default': True,
+        },
     }
 
     def print_label(self, **kwargs):
@@ -103,10 +115,8 @@ class BrotherLabelPlugin(LabelPrintingMixin, SettingsMixin, InvenTreePlugin):
 
         # Read settings
         model = self.get_setting('MODEL')
-        label = self.get_setting('LABEL')
         ip_address = self.get_setting('IP_ADDRESS')
-        auto_cut = self.get_setting('AUTO_CUT')
-        rotation = self.get_setting('ROTATION')
+        label = self.get_setting('LABEL')
 
         # Check if red labels used
         if label in ['62red']:
@@ -120,17 +130,14 @@ class BrotherLabelPlugin(LabelPrintingMixin, SettingsMixin, InvenTreePlugin):
         params = {
             'qlr': printer,
             'images': [label_image],
-            'cut': auto_cut,
-            'rotate': rotation,
-            'hq': True,
             'label': label,
+            'cut': self.get_setting('AUTO_CUT'),
+            'rotate': self.get_setting('ROTATION'),
+            'compress': self.get_setting('COMPRESSION'),
+            'hq': self.get_setting('HQ'),
             'red': red,
         }
 
-        if model in ['PT-P750W', 'PT-P900W']:
-            # Override compression setting for these printers
-            params['compress'] = True
-
         instructions = convert(**params)
 
         send(
